"""
Blessed Google-Ads connector for Airbyte SDK.

Auto-generated from OpenAPI specification.
"""

from .connector import GoogleAdsConnector
from .models import (
    GoogleAdsAuthConfig,
    GoogleAdsReplicationConfig,
    AccessibleCustomerResourceName,
    AccessibleCustomersList,
    AccountCustomerConversiontrackingsetting,
    AccountCustomerCallreportingsetting,
    AccountCustomerRemarketingsetting,
    AccountCustomer,
    Account,
    AccountSearchResponse,
    CampaignCampaignNetworksettings,
    CampaignCampaign,
    CampaignCampaignbudget,
    CampaignMetrics,
    CampaignSegments,
    Campaign,
    CampaignSearchResponse,
    AdGroupMetrics,
    AdGroupSegments,
    AdGroupCampaign,
    AdGroupAdgroup,
    AdGroup,
    AdGroupSearchResponse,
    AdGroupAdSegments,
    AdGroupAdAdgroup,
    AdGroupAdAdgroupadPolicysummary,
    AdGroupAdAdgroupadAd,
    AdGroupAdAdgroupad,
    AdGroupAd,
    AdGroupAdSearchResponse,
    CampaignLabelCampaign,
    CampaignLabelCampaignlabel,
    CampaignLabelLabel,
    CampaignLabel,
    CampaignLabelSearchResponse,
    AdGroupLabelLabel,
    AdGroupLabelAdgroup,
    AdGroupLabelAdgrouplabel,
    AdGroupLabel,
    AdGroupLabelSearchResponse,
    AdGroupAdLabelLabel,
    AdGroupAdLabelAdgroupadAd,
    AdGroupAdLabelAdgroupad,
    AdGroupAdLabelAdgroupadlabel,
    AdGroupAdLabel,
    AdGroupAdLabelSearchResponse,
    CampaignMutateRequestOperationsItemUpdate,
    CampaignMutateRequestOperationsItem,
    CampaignMutateRequest,
    CampaignMutateResponseResultsItem,
    CampaignMutateResponse,
    AdGroupMutateRequestOperationsItemUpdate,
    AdGroupMutateRequestOperationsItem,
    AdGroupMutateRequest,
    AdGroupMutateResponseResultsItem,
    AdGroupMutateResponse,
    LabelMutateRequestOperationsItemCreateTextlabel,
    LabelMutateRequestOperationsItemCreate,
    LabelMutateRequestOperationsItem,
    LabelMutateRequest,
    LabelMutateResponseResultsItem,
    LabelMutateResponse,
    CampaignLabelMutateRequestOperationsItemCreate,
    CampaignLabelMutateRequestOperationsItem,
    CampaignLabelMutateRequest,
    CampaignLabelMutateResponseResultsItem,
    CampaignLabelMutateResponse,
    AdGroupLabelMutateRequestOperationsItemCreate,
    AdGroupLabelMutateRequestOperationsItem,
    AdGroupLabelMutateRequest,
    AdGroupLabelMutateResponseResultsItem,
    AdGroupLabelMutateResponse,
    AccountsListResultMeta,
    CampaignsListResultMeta,
    AdGroupsListResultMeta,
    AdGroupAdsListResultMeta,
    CampaignLabelsListResultMeta,
    AdGroupLabelsListResultMeta,
    AdGroupAdLabelsListResultMeta,
    GoogleAdsCheckResult,
    GoogleAdsExecuteResult,
    GoogleAdsExecuteResultWithMeta,
    AccessibleCustomersListResult,
    AccountsListResult,
    CampaignsListResult,
    AdGroupsListResult,
    AdGroupAdsListResult,
    CampaignLabelsListResult,
    AdGroupLabelsListResult,
    AdGroupAdLabelsListResult,
    AirbyteSearchMeta,
    AirbyteSearchResult,
    AccountsSearchData,
    AccountsSearchResult,
    CampaignsSearchData,
    CampaignsSearchResult,
    AdGroupsSearchData,
    AdGroupsSearchResult,
    AdGroupAdsSearchData,
    AdGroupAdsSearchResult,
    CampaignLabelsSearchData,
    CampaignLabelsSearchResult,
    AdGroupLabelsSearchData,
    AdGroupLabelsSearchResult,
    AdGroupAdLabelsSearchData,
    AdGroupAdLabelsSearchResult
)
from .types import (
    CampaignsUpdateParamsOperationsItemUpdate,
    CampaignsUpdateParamsOperationsItem,
    AdGroupsUpdateParamsOperationsItemUpdate,
    AdGroupsUpdateParamsOperationsItem,
    LabelsCreateParamsOperationsItemCreateTextlabel,
    LabelsCreateParamsOperationsItemCreate,
    LabelsCreateParamsOperationsItem,
    CampaignLabelsCreateParamsOperationsItemCreate,
    CampaignLabelsCreateParamsOperationsItem,
    AdGroupLabelsCreateParamsOperationsItemCreate,
    AdGroupLabelsCreateParamsOperationsItem,
    AccessibleCustomersListParams,
    AccountsListParams,
    CampaignsListParams,
    AdGroupsListParams,
    AdGroupAdsListParams,
    CampaignLabelsListParams,
    AdGroupLabelsListParams,
    AdGroupAdLabelsListParams,
    CampaignsUpdateParams,
    AdGroupsUpdateParams,
    LabelsCreateParams,
    CampaignLabelsCreateParams,
    AdGroupLabelsCreateParams,
    AirbyteSearchParams,
    AirbyteSortOrder,
    AccountsSearchFilter,
    AccountsSearchQuery,
    AccountsCondition,
    CampaignsSearchFilter,
    CampaignsSearchQuery,
    CampaignsCondition,
    AdGroupsSearchFilter,
    AdGroupsSearchQuery,
    AdGroupsCondition,
    AdGroupAdsSearchFilter,
    AdGroupAdsSearchQuery,
    AdGroupAdsCondition,
    CampaignLabelsSearchFilter,
    CampaignLabelsSearchQuery,
    CampaignLabelsCondition,
    AdGroupLabelsSearchFilter,
    AdGroupLabelsSearchQuery,
    AdGroupLabelsCondition,
    AdGroupAdLabelsSearchFilter,
    AdGroupAdLabelsSearchQuery,
    AdGroupAdLabelsCondition
)
from ._vendored.connector_sdk.types import AirbyteHostedAuthConfig as AirbyteAuthConfig

__all__ = [
    "GoogleAdsConnector",
    "AirbyteAuthConfig",
    "GoogleAdsAuthConfig",
    "GoogleAdsReplicationConfig",
    "AccessibleCustomerResourceName",
    "AccessibleCustomersList",
    "AccountCustomerConversiontrackingsetting",
    "AccountCustomerCallreportingsetting",
    "AccountCustomerRemarketingsetting",
    "AccountCustomer",
    "Account",
    "AccountSearchResponse",
    "CampaignCampaignNetworksettings",
    "CampaignCampaign",
    "CampaignCampaignbudget",
    "CampaignMetrics",
    "CampaignSegments",
    "Campaign",
    "CampaignSearchResponse",
    "AdGroupMetrics",
    "AdGroupSegments",
    "AdGroupCampaign",
    "AdGroupAdgroup",
    "AdGroup",
    "AdGroupSearchResponse",
    "AdGroupAdSegments",
    "AdGroupAdAdgroup",
    "AdGroupAdAdgroupadPolicysummary",
    "AdGroupAdAdgroupadAd",
    "AdGroupAdAdgroupad",
    "AdGroupAd",
    "AdGroupAdSearchResponse",
    "CampaignLabelCampaign",
    "CampaignLabelCampaignlabel",
    "CampaignLabelLabel",
    "CampaignLabel",
    "CampaignLabelSearchResponse",
    "AdGroupLabelLabel",
    "AdGroupLabelAdgroup",
    "AdGroupLabelAdgrouplabel",
    "AdGroupLabel",
    "AdGroupLabelSearchResponse",
    "AdGroupAdLabelLabel",
    "AdGroupAdLabelAdgroupadAd",
    "AdGroupAdLabelAdgroupad",
    "AdGroupAdLabelAdgroupadlabel",
    "AdGroupAdLabel",
    "AdGroupAdLabelSearchResponse",
    "CampaignMutateRequestOperationsItemUpdate",
    "CampaignMutateRequestOperationsItem",
    "CampaignMutateRequest",
    "CampaignMutateResponseResultsItem",
    "CampaignMutateResponse",
    "AdGroupMutateRequestOperationsItemUpdate",
    "AdGroupMutateRequestOperationsItem",
    "AdGroupMutateRequest",
    "AdGroupMutateResponseResultsItem",
    "AdGroupMutateResponse",
    "LabelMutateRequestOperationsItemCreateTextlabel",
    "LabelMutateRequestOperationsItemCreate",
    "LabelMutateRequestOperationsItem",
    "LabelMutateRequest",
    "LabelMutateResponseResultsItem",
    "LabelMutateResponse",
    "CampaignLabelMutateRequestOperationsItemCreate",
    "CampaignLabelMutateRequestOperationsItem",
    "CampaignLabelMutateRequest",
    "CampaignLabelMutateResponseResultsItem",
    "CampaignLabelMutateResponse",
    "AdGroupLabelMutateRequestOperationsItemCreate",
    "AdGroupLabelMutateRequestOperationsItem",
    "AdGroupLabelMutateRequest",
    "AdGroupLabelMutateResponseResultsItem",
    "AdGroupLabelMutateResponse",
    "AccountsListResultMeta",
    "CampaignsListResultMeta",
    "AdGroupsListResultMeta",
    "AdGroupAdsListResultMeta",
    "CampaignLabelsListResultMeta",
    "AdGroupLabelsListResultMeta",
    "AdGroupAdLabelsListResultMeta",
    "GoogleAdsCheckResult",
    "GoogleAdsExecuteResult",
    "GoogleAdsExecuteResultWithMeta",
    "AccessibleCustomersListResult",
    "AccountsListResult",
    "CampaignsListResult",
    "AdGroupsListResult",
    "AdGroupAdsListResult",
    "CampaignLabelsListResult",
    "AdGroupLabelsListResult",
    "AdGroupAdLabelsListResult",
    "AirbyteSearchMeta",
    "AirbyteSearchResult",
    "AccountsSearchData",
    "AccountsSearchResult",
    "CampaignsSearchData",
    "CampaignsSearchResult",
    "AdGroupsSearchData",
    "AdGroupsSearchResult",
    "AdGroupAdsSearchData",
    "AdGroupAdsSearchResult",
    "CampaignLabelsSearchData",
    "CampaignLabelsSearchResult",
    "AdGroupLabelsSearchData",
    "AdGroupLabelsSearchResult",
    "AdGroupAdLabelsSearchData",
    "AdGroupAdLabelsSearchResult",
    "CampaignsUpdateParamsOperationsItemUpdate",
    "CampaignsUpdateParamsOperationsItem",
    "AdGroupsUpdateParamsOperationsItemUpdate",
    "AdGroupsUpdateParamsOperationsItem",
    "LabelsCreateParamsOperationsItemCreateTextlabel",
    "LabelsCreateParamsOperationsItemCreate",
    "LabelsCreateParamsOperationsItem",
    "CampaignLabelsCreateParamsOperationsItemCreate",
    "CampaignLabelsCreateParamsOperationsItem",
    "AdGroupLabelsCreateParamsOperationsItemCreate",
    "AdGroupLabelsCreateParamsOperationsItem",
    "AccessibleCustomersListParams",
    "AccountsListParams",
    "CampaignsListParams",
    "AdGroupsListParams",
    "AdGroupAdsListParams",
    "CampaignLabelsListParams",
    "AdGroupLabelsListParams",
    "AdGroupAdLabelsListParams",
    "CampaignsUpdateParams",
    "AdGroupsUpdateParams",
    "LabelsCreateParams",
    "CampaignLabelsCreateParams",
    "AdGroupLabelsCreateParams",
    "AirbyteSearchParams",
    "AirbyteSortOrder",
    "AccountsSearchFilter",
    "AccountsSearchQuery",
    "AccountsCondition",
    "CampaignsSearchFilter",
    "CampaignsSearchQuery",
    "CampaignsCondition",
    "AdGroupsSearchFilter",
    "AdGroupsSearchQuery",
    "AdGroupsCondition",
    "AdGroupAdsSearchFilter",
    "AdGroupAdsSearchQuery",
    "AdGroupAdsCondition",
    "CampaignLabelsSearchFilter",
    "CampaignLabelsSearchQuery",
    "CampaignLabelsCondition",
    "AdGroupLabelsSearchFilter",
    "AdGroupLabelsSearchQuery",
    "AdGroupLabelsCondition",
    "AdGroupAdLabelsSearchFilter",
    "AdGroupAdLabelsSearchQuery",
    "AdGroupAdLabelsCondition",
]